@@ -128,7 +128,7 @@ class BaseProtocol:
                     counter += 1                    
                     await asyncio.sleep(10+counter)
                 continue
-            except ConnectionResetError, ConnectionAbortedError as conn_error:
+            except (ConnectionResetError, ConnectionAbortedError) as conn_error:
                 self.logger("Excepción por desconexión %s"%conn_error)
                 continue                
             except Exception as e:
@@ -232,14 +232,14 @@ class BaseProtocol:
             print("Incomplete read, station %s" %self.station, reader, n)
             self.logger.exception("Station %s, Tiempo fuera al no poder leer en readbytes %s bytes, %s"%(n, self.station,ir))
             return None
-        except ConnectionResetError, ConnectionAbortedError as conn_error:
+        except (ConnectionResetError, ConnectionAbortedError) as conn_error:
             self.logger("Excepción por desconexión al intentar leer %s"%conn_error)
-            continue                
+            return None
         except Exception as e:
             print("Excepción no considerada")
             self.logger("Excepción no considerada al intentar leer%s"%e)
-            continue
-
+            return None
+        
     async def get_message_header(self, idc):
         self.idc = idc
 
